# Misite Bao

Hi, I am Misite Bao.

## Usage

Run the following command in the terminal to install `misitebao`:

```shell
pip install misitebao
```

Once that's done, you can run this command inside the terminal...

```shell
misitebao
```
